#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `crm_claim` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-crm-claim",
    version = "7.0.406",
    description = "Claims Management",
    long_description = 
"""


Manage Customer Claims.
=======================
This application allows you to track your customers/suppliers claims and grievances.

It is fully integrated with the email gateway so that you can create
automatically new claims based on incoming emails.
    
""",
    url = "http://www.openerp.com",
    author = "OpenERP SA",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.crm_claim': ".",
    },
    packages = ["openerp.addons.crm_claim","openerp.addons.crm_claim.report"],
    package_data = {
        'openerp.addons.crm_claim': ["i18n/*.po*","res_config_view.xml","crm_claim_view.xml","crm_claim_menu.xml","crm_claim_data.xml","crm_claim_demo.xml","images/claim_stages.jpeg","images/claims.jpeg","images/claim_categories.jpeg","i18n/hr.po","i18n/da.po","i18n/sl.po","i18n/es_MX.po","i18n/ru.po","i18n/zh_TW.po","i18n/cs.po","i18n/sq.po","i18n/fi.po","i18n/pt_BR.po","i18n/ko.po","i18n/gu.po","i18n/bg.po","i18n/es_VE.po","i18n/es_PY.po","i18n/ja.po","i18n/ro.po","i18n/sr@latin.po","i18n/es.po","i18n/mn.po","i18n/it.po","i18n/nl.po","i18n/sv.po","i18n/es_EC.po","i18n/bs.po","i18n/tr.po","i18n/de.po","i18n/sr.po","i18n/lt.po","i18n/hu.po","i18n/el.po","i18n/gl.po","i18n/mk.po","i18n/ca.po","i18n/fr.po","i18n/zh_CN.po","i18n/pl.po","i18n/nb.po","i18n/ar.po","i18n/pt.po","i18n/es_CR.po","test/customer_claim.eml","test/ui/claim_demo.yml","test/process/claim.yml","security/ir.model.access.csv","report/crm_claim_report_view.xml","crm_claim_view.xml","crm_claim_menu.xml","security/ir.model.access.csv","report/crm_claim_report_view.xml","res_config_view.xml","crm_claim_data.xml","crm_claim_demo.xml"],
    },
    install_requires = ["openerp-crm"],
    tests_require = ["unittest2"],
)
